@@ -3,11 +3,14 @@ use feature qw/say/;
 use Moo;
 
 use Chef::Knife::Cmd::Node::RunList;
+use Chef::Knife::Cmd::Node::From;
 
 has knife    => (is => 'ro', required => 1, handles => [qw/handle_options run/]);
 has run_list => (is => 'lazy');
+has from     => (is => 'lazy');
 
 sub _build_run_list { Chef::Knife::Cmd::Node::RunList->new(knife => shift) }
+sub _build_from     { Chef::Knife::Cmd::Node::From->new(knife => shift) }
 
 sub show {
     my ($self, $node, %options) = @_;
